# Multi-Agent Networking

Connect and collaborate between agents.

## Core Concepts

- [host.md](host.md) - Make agents network-accessible with `host()`
- [connect.md](connect.md) - Connect to remote agents with `connect()`

## Protocol Specifications

- [protocol/agent-relay-protocol.md](protocol/agent-relay-protocol.md) - Agent relay protocol spec
- [protocol/announce-message.md](protocol/announce-message.md) - Service announcement protocol
